<div align="center">
<img src="https://github.com/cleragui/pypi/blob/main/image/logo-with-name.png?raw=true">
</div>

## **Clera - GUI Development with Python** 
![PyPI Downloads](https://static.pepy.tech/badge/clera)

---

Clera provides platform for developing python GUI quickly and simply with low learning curve.

<br>

> **NOTE:** Clera is still in the **alpha** stage which means development is not complete its undergoing internal tests and development. To help with the testing process or need tutorial on how to use clera, please send me an email eirasmx@pm.me

<br>

## **THE BASICS**

### **Installation**

```bash
pip install clera
```

Your first application and Skeleton of every GUI developed using clera.

**Code:**

```python
from clera import Window
window = Window()
# window widgets and layouts goes here!
window.run()
```

**Output:**

![Window](https://github.com/cleragui/pypi/blob/main/image/window.png?raw=true)

> **" Why Complicate Simplicity? "**

<br>

## **PLATFORMS**

> Clera runs on multiple platforms and has a native interface on each.

### **Hardware Support**

- Runs on Desktop and Laptops

### **OS Support**

- Windows
- Mac
- Linux

<br>

To run the clera style editor, run "**clera-editor**" in the terminal or command prompt and "**clera-deploy**" to run the clera deploy tool. Also to see a sample of what clera is capable of, check out the editor. It's developed with clera!

<br>

> **INFO:** Visit https://clera.readthedocs.io for documentation and more information.

<br>

---

<br>

### **RELEASE NOTES**

**v0.2.6 (2026-02-10) - Various fixes and additions**

- Web Engine (**added**)    
- Overlay Widget (**added**)   
- Popup details (**added**)   

<br>
  
- NoneType Crashes (**fixed**)    
- Popup Modal Behavior (**fixed**)    

<br>

- Clera Editor (**upgraded**)   

<br>

---
